//	OptionsSlider.cpp - Simple slider class for the options screen.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "OptionsSlider.h"

//------------------------------------------------------------------------------
OptionsSlider::OptionsSlider(const TwoFloats& pos, const ThreeFloats& col):
value(0.0f),
position(pos),
colour(col),
big(false),
tweener(position, position, 0.1f)
{
	tweener.setIndex(1.0f);
}

//------------------------------------------------------------------------------
OptionsSlider::~OptionsSlider()
{

}

//------------------------------------------------------------------------------
void OptionsSlider::update()
{
	if(!tweener.getFinished())
		tweener.tick();
}

//------------------------------------------------------------------------------
void OptionsSlider::draw(shared_ptr<Drawer>& d)
{
	if(big)
	{
		TwoFloats trackPos(position.x, position.y-48.0f-8.0f);
		TwoFloats thumbPos(position.x+(value*440.0f)-24.0f, position.y-48.0f-32.0f);

		//The shadows
		d->fillRect(trackPos+3.0f, TwoFloats(440.0f, 16.0f), 0.0f);
		d->fillRect(thumbPos+3.0f, TwoFloats(48.0f, 64.0f), 0.0f);

		//The foreground.
		d->fillRect(trackPos, TwoFloats(440.0f, 16.0f), colour);
		d->fillRect(thumbPos, TwoFloats(48.0f, 64.0f), colour);
	}
	else
	{
		TwoFloats trackPos(position.x, position.y-32.0f-4.0f);
		TwoFloats thumbPos(position.x+(value*440.0f)-16.0f, position.y-32.0f-24.0f);

		//The shadows
		d->fillRect(trackPos+3.0f, TwoFloats(440.0f, 8.0f), 0.0f);
		d->fillRect(thumbPos+3.0f, TwoFloats(32.0f, 48.0f), 0.0f);

		//The foreground.
		d->fillRect(trackPos, TwoFloats(440.0f, 8.0f), colour);
		d->fillRect(thumbPos, TwoFloats(32.0f, 48.0f), colour);
	}
}

//------------------------------------------------------------------------------
void OptionsSlider::setPosition(const TwoFloats& pos)
{
	tweener.reset(pos);
}

//------------------------------------------------------------------------------
void OptionsSlider::setValue(float val)
{
	value = val;
}

//------------------------------------------------------------------------------
void OptionsSlider::incValue(float val)
{
	value += val;
	if(value < 0.0f)
		value = 0.0f;
	else if(value > 1.0f)
		value = 1.0f;
}

//------------------------------------------------------------------------------
void OptionsSlider::setBig(bool val)
{
	big = val;
}
