//	OptionsSlider.h - Simple slider class for the options screen.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef OPTIONSSLIDER_H_
#define OPTIONSSLIDER_H_

#include "ThreeFloats.h"
#include "c0xHeaders.h"
#include "TwoFloats.h"
#include "Tweener.h"

class Drawer;

///	Simple slider class for the options screen.
class OptionsSlider
{
  public:
	///	Constructor.
	OptionsSlider(const TwoFloats& pos, const ThreeFloats& col);
	///	Destructor.
	~OptionsSlider();

	///	Moves the slider if necessary.
	void update();
	///	Draws the slider.
	void draw(shared_ptr<Drawer>& d);

	///	Sets the slider's position.
	void setPosition(const TwoFloats& pos);

	///	Sets the slider's value.
	void setValue(float val);
	///	Increments/decrements the slider's value.
	void incValue(float val);
	///	Returns the slider's value.
	float getValue() const {return value;};

	///	Toggles the slider big/small.
	void setBig(bool val);
  private:
	///	The slider's value (0->1).
	float value;
	///	The slider's position.
	TwoFloats position;
	///	The slider's colour.
	ThreeFloats colour;
	///	Whether the slider is current big or small.
	bool big;

	///	Used to move the slider about over time.
	STweener<TwoFloats> tweener;
};

#endif
