//	TitleScreen.h - The title screen state.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef TITLESCREEN_H_
#define TITLESCREEN_H_

#include "drawing/TextLayout.h"
#include "ThreeFloats.h"
#include "GameState.h"
#include "Tweener.h"

class ScreamingSnakeballGlobalData;

///	The title screen state.
class TitleScreen : public GameState
{
  public:
	///	Constructor.
	TitleScreen(Application& app, SounderPtr& sound);
	///	Destructor.
	~TitleScreen();

	///	Called frequently to update the state.
	void update();
	///	Called to draw the state.
	void draw(DrawerPtr& d, float timestepInterp);

	///	Called when a key down event is received.
	void keyDown(const std::wstring& action,
				 const std::wstring& keyPressed,
				 int keyModifier);
	///	Called when a joystick axis changes.
	void joyMove(const std::wstring& action,
				 float value,
				 int joystick,
				 int axis);

	///	Returns the name of this state.
	const std::wstring getName() const {return L"TitleScreen";};
	///	Used to construct instances of this state.
	static GameStateCreator<TitleScreen> creator;
  private:
	///	Struct representing a single entry in the menu.
	struct MenuEntry
	{
		///	The entry's position.
		TwoFloats position;
		///	The entry's colour.
		ThreeFloats colour;
		///	The entry's text.
		std::wstring text;
		///	The entry's font.
		std::wstring font;
		///	The entry's TextLayout.
		TextLayout layout;
	};

	///	The menu entries.
	/*!
		For simplicity (laziness) we store the positions for each entry for each
		of the four possible arrangements.
	 */
	MenuEntry entries[5][5];
	///	The four menu entry positions we use.
	TwoFloats entryPos[5];
	///	The position tweener for the first menu entry.
	STweener<TwoFloats> entryTween0;
	///	The position tweener for the second menu entry.
	STweener<TwoFloats> entryTween1;
	///	The position tweener for the third menu entry.
	STweener<TwoFloats> entryTween2;
	///	The position tweener for the fourth menu entry.
	STweener<TwoFloats> entryTween3;
	///	The position tweener for the fifth menu entry.
	STweener<TwoFloats> entryTween4;
	///	The currently-selected menu entry.
	int selectedEntry;

	///	Used to handle menu navigation with a joystick.
	float lastJoyVal;
	///	Used to handle menu navigation with a joystick.
	int joyRepeat;

	///	Our global data.
	shared_ptr<ScreamingSnakeballGlobalData> globalData;
	
	///	Used to fade in after the loading screen.
	float fadeIn;
	///	Used to fade in after the loading screen.
	STweener<float> fadeInTween;
	///	Used to fade in after the loading screen.
	static bool firstRun;

	///	Used to fade out on quit.
	STweener<float> fadeOutTween;
};

#endif
